@@ -2,6 +2,8 @@
 URL_LOGIN = "/dyn/login.json"
 URL_LOGOUT = "/dyn/logout.json"
 URL_VALUES = "/dyn/getValues.json"
+URL_ALL_VALUES = "/dyn/getAllOnlValues.json"
+URL_ALL_PARAMS = "/dyn/getAllParamValues.json"
 URL_LOGGER = "/dyn/getLogger.json"
 URL_DASH_LOGGER = "/dyn/getDashLogger.json"
 URL_DASH_VALUES = "/dyn/getDashValues.json"
@@ -13,7 +15,7 @@ DEFAULT_TIMEOUT = 15
 JMESPATH_VAL = "val"
 JMESPATH_VAL_TAG = JMESPATH_VAL + "[0].tag"
 JMESPATH_VAL_STR = "[?str==sum([`1`,`{}`])].val | [0]"
-JMESPATH_VAL_IDX = '"{}"[{}].val'
+JMESPATH_VAL_IDX = "* | [0][{}].val"
 JMESPATH_VAL_IDX_TAG = JMESPATH_VAL_IDX + "[0].tag"
 
 JMESPATHS_TAG = (JMESPATH_VAL_IDX_TAG, JMESPATH_VAL_TAG)
@@ -37,12 +39,7 @@ FALLBACK_DEVICE_INFO = {
     "serial": "9999999999",
 }
 
-DEVCLASS_INVERTER = "1"
-DEVCLASS_BATTERY = "7"
-DEVCLASS_ENERGY_METER = "65"
-OPTIMIZERS_VIA_INVERTER = "253"
-ENERGY_METER_VIA_INVERTER = "254"
-DEVICE_INFO = "255"
-
-ENTITY_CATEGORY_CONFIG = "config"
-ENTITY_CATEGORY_DIAGNOSTIC = "diagnostic"
+GENERIC_SENSORS = "generic"
+OPTIMIZERS_VIA_INVERTER = "optimizers"
+ENERGY_METER_VIA_INVERTER = "energy-meter"
+DEVICE_INFO = "device-info"
